exceptiontools.SpannerError
===========================

.. inheritance-diagram:: abjad.tools.exceptiontools.SpannerError.SpannerError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.SpannerError.SpannerError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.SpannerError.SpannerError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
